pub struct NodeSegment {
pub segment_type: SegmentType,
pub children: Vec<Segment>,
pub span: Span,
}Expand description
A branch segment grouping children under a named production.
Fields
segment_type: SegmentTypechildren: Vec<Segment>span: SpanImplementations
Sourceimpl NodeSegment
impl NodeSegment
Sourcepub fn new(segment_type: SegmentType, children: Vec<Segment>) -> Self
pub fn new(segment_type: SegmentType, children: Vec<Segment>) -> Self
Create a new node from children, computing span automatically.